package pps.core.base.utils;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.apache.commons.lang3.StringUtils;
import pps.cloud.system.service.SystemDictionaryService;
import pps.cloud.system.service.data.QuerySysDictionaryViewInput;
import pps.cloud.system.service.data.QuerySysDictionaryViewOutput;
import pps.core.base.entity.BasePowerLineEnt;
import pps.core.base.mapper.BasePowerLineMapper;
import xstartup.base.XContext;
import xstartup.data.XListResult;

import java.util.List;

/**
 * 封装工具类
 *
 * @author ZWT
 * @date 2023/08/25 16:08
 */
public class DictUtils {

    /**
     * 通过字典类型查询字典
     *
     * @param context 上下文
     * @param alias   别名
     * @return {@link List}<{@link QuerySysDictionaryViewOutput}>
     */
    public static List<QuerySysDictionaryViewOutput> getDictList(XContext context, String alias) {
        QuerySysDictionaryViewInput dictInput = new QuerySysDictionaryViewInput();
        dictInput.setAlias(alias);
        dictInput.setPage(1);
        dictInput.setLimit(999);
        SystemDictionaryService dictionaryService = context.getBean(SystemDictionaryService.class);
        XListResult<QuerySysDictionaryViewOutput> dictPageResult = dictionaryService.queryChildSysDictionarysByParentAlias(context, dictInput);
        dictPageResult.throwIfFail();
        return dictPageResult.getResult();
    }

    /**
     * 通过字典编码匹配查询字典名称
     *
     * @param dictList dict类型列表
     * @param dicKey   dic关键
     * @return {@link String}
     */
    public static String getDicNameByStream(List<QuerySysDictionaryViewOutput> dictList, String dicKey) {
        return dictList.stream()
                .filter(row -> StringUtils.equals(row.getDicKey(), dicKey))
                .map(QuerySysDictionaryViewOutput::getDicName)
                .findAny()
                .orElse(null);
    }

    /**
     * 检查市电峰谷策略是否被引用
     *
     * @param context    上下文
     * @param strategyId 战略id
     * @return boolean
     */
    public static boolean checkStrategyIsReference(XContext context, String strategyId) {
        BasePowerLineMapper mapper = context.getBean(BasePowerLineMapper.class);
        Long count = mapper.selectCount(new LambdaQueryWrapper<BasePowerLineEnt>()
                .eq(BasePowerLineEnt::getStrategyId, strategyId)
        );
        return count > 0;
    }
}